
export interface Plugin {
  id: string
  module: string
  description: string
}

export interface WorkflowPlugin extends Plugin {
  wf: Workflow
}

interface Plugins_ {
  api: {[id: string] : Plugin}
  workflow: { [id: string]: WorkflowPlugin }
  cli: { [id: string]: Plugin }
  settings: {[id: string] : Plugin}
}

export interface ApiServerInfo {
  version?: string
  hatchet_url?: string
  api_doc?: string
  plugins?: Plugins_
}

export interface HatchetWorker {
    name: string
    status: string
    config: Object
}

export interface TaskDefault {
  schedule_timeout: number
  execution_timeout: number
  priority: number
  retries: number
  backoff_factor: number
  backoff_max_seconds: number
}

export interface InputValidatorType {
  type: string
}

export interface InputValidatorProperties {
  default: boolean
  title: string
  type?: string
  anyOf?: InputValidatorType[]
  optional?: boolean
}

export interface InputValidator {
  title: string
  type: string
  properties: {[name: string]: InputValidatorProperties}
}

export interface WorkflowConfig {
  on_events: string[]
  on_crons: string[]
  concurrency: number
  input_validator?: InputValidator
  default_priority: number
  //task_defaults: TaskDefault
  description: string
  name: string
  version: string
}

export interface Workflow {
  config: WorkflowConfig
  id: string
  name: string
  is_durable: string
  service_name: string
  tasks: string[]
}

export interface Workflows {
  [name: string]: Workflow
}

export interface TaskResult_ {
    [name: string]: string
}

export interface WorkflowRunResultTasks {
    [name: string]: TaskResult_
}

export interface WorkflowRunErrorTasks {
    [name: string]: string
}

export interface WorkflowTriggerResult {
    wfRunId: string
}

export interface WorkflowInput {
    [name: string]: string | boolean | number
}

export interface WorkflowRunResult {
    wf: Workflow
    wfRunId: string
    result: WorkflowRunResultTasks
    error: WorkflowRunErrorTasks
    payload?: string
    input?: WorkflowInput
    status: string
    finishedAt: Date
    duration: number
}

export interface WorkflowRunResults {
  [wfRunId: string]: WorkflowRunResult
}

export interface WFSubscriptions {
    [wfId: string]: Workflow
}

export interface Subscriptions {
    wfs: WFSubscriptions
}
export interface MenuDef {
  label?: string
  icon?: string
  route?: string
}
